@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
-from .core import aioresponses
+from .core import CallbackResult, aioresponses
 
 __version__ = '0.4.1'
 
 __all__ = [
+    'CallbackResult',
     'aioresponses',
 ]
